@@ -2,7 +2,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -205,7 +205,7 @@ convert_file(char *file_name)
 
     Free_safe(line);
 
-    fclose(f);
+    xfclose(&f);
 
     /* open a temp file in write mode and truncate it */
     strcpy(buf, "tmp_");
