@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -603,7 +603,7 @@ talk_fcron(char *cmd_str, int fd)
         error_e("error in recv()");
 
     if (!existing_connection)
-        close(fd);
+        xclose_check(&fd, "unix socket");
 
     return OK;
 }
@@ -692,7 +692,7 @@ interactive_mode(int fd)
         if (line_read && *line_read) {
             add_history(line_read);
         }
-#endif
+#endif                          /* HAVE_READLINE_HISTORY */
 
         free(line_read);
         if (return_code == QUIT_CMD || return_code == ERR) {
@@ -707,7 +707,7 @@ interactive_mode(int fd)
 #endif                          /* HAVE_LIBREADLINE */
 
     if (!existing_connection)
-        close(fd);
+        xclose_check(&fd, "unix socket");
 
     return OK;
 }
@@ -779,7 +779,7 @@ int
 main(int argc, char **argv)
 {
     int return_code = 0;
-    int fd = (-1);
+    int fd = (-1);              /* fd == -1 means connection to fcron is not currently open */
     struct passwd *pass = NULL;
 
     rootuid = get_user_uid_safe(ROOTNAME);
