@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1343,6 +1343,19 @@ read_shortcut(char *ptr, cf_t * cf)
         return 0;
     }
 
+    /* The next char must be a space (no other option allowed when using
+     * a shortcut: if the user wants to use options, they should use the 
+     * native fcron lines */
+    if (!isspace((int)*ptr)) {
+        fprintf(stderr, "%s:%d: No space after shortcut: skipping line.\n",
+                file_name, line);
+        goto exiterr;
+    }
+
+    /* skip spaces before the username / shell command */
+    while (isspace((int)*ptr))
+        ptr++;
+
     /* check for inline runas */
     ptr = check_username(ptr, cf, cl);
 
@@ -1449,7 +1462,7 @@ read_freq(char *ptr, cf_t * cf)
 
 #ifndef USE_SENDMAIL
     clear_mail(cl->cl_option);
-    clear_forcemail(cl->cl_option);
+    clear_mailzerolength(cl->cl_option);
 #endif
 
     cl->cl_next = cf->cf_line_base;
@@ -1553,7 +1566,7 @@ read_arys(char *ptr, cf_t * cf)
 
 #ifndef USE_SENDMAIL
     clear_mail(cl->cl_option);
-    clear_forcemail(cl->cl_option);
+    clear_mailzerolength(cl->cl_option);
 #endif
 
     cl->cl_next = cf->cf_line_base;
@@ -1708,7 +1721,7 @@ read_period(char *ptr, cf_t * cf)
  ok:
 #ifndef USE_SENDMAIL
     clear_mail(cl->cl_option);
-    clear_forcemail(cl->cl_option);
+    clear_mailzerolength(cl->cl_option);
 #endif
 
     cl->cl_next = cf->cf_line_base;
