@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -232,6 +232,7 @@ typedef struct job_t {
 #include "log.h"
 /* functions used by fcrontab, fcrondyn, and fcron */
 #include "subs.h"
-
+/* file related helper functions */
+#include "filesubs.h"
 
 #endif                          /* __GLOBAL_H__ */
