@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -869,10 +869,10 @@ remove_connection(struct fcrondyn_cl **client, struct fcrondyn_cl *prev_client)
 /* close the connection, remove it from the list 
 and make client points to the next entry */
 {
+    debug("closing connection : fd : %d", (*client)->fcl_sock_fd);
     shutdown((*client)->fcl_sock_fd, SHUT_RDWR);
-    close((*client)->fcl_sock_fd);
     remove_from_select_set((*client)->fcl_sock_fd, &master_set, &set_max_fd);
-    debug("connection closed : fd : %d", (*client)->fcl_sock_fd);
+    xclose_check(&((*client)->fcl_sock_fd), "client fd");
     if (prev_client == NULL) {
         fcrondyn_cl_base = (*client)->fcl_next;
         Free_safe((*client)->fcl_user);
@@ -920,7 +920,7 @@ check_socket(int num)
                 error_e
                     ("Could not set fd attribute O_NONBLOCK : connection rejected.");
                 shutdown(fd, SHUT_RDWR);
-                close(fd);
+                xclose_check(&fd, "client fd");
             }
             else {
                 Alloc(client, fcrondyn_cl);
@@ -1017,13 +1017,13 @@ close_socket(void)
 
     if (listen_fd) {
         shutdown(listen_fd, SHUT_RDWR);
-        close(listen_fd);
+        xclose_check(&listen_fd, "listening fd");
         unlink(fifofile);
 
         client = fcrondyn_cl_base;
         while (client != NULL) {
             shutdown(client->fcl_sock_fd, SHUT_RDWR);
-            close(client->fcl_sock_fd);
+            xclose_check(&(client->fcl_sock_fd), "client fd");
 
             client_buf = client->fcl_next;
             Free_safe(client);
